##### Images

To present your data you probably want to use images. Maybe you want to create a slideshow or show some figures. NDR Core organizes images in groups, used for different purposes.

###### Image Groups

- Figure Images: If you want to show a properly resized image with a caption and a link to an outside source, this is the category you want. You'll find the code to include the figure in your template text below the images.
- Footer Partner Images: Your footer is a good place to display the partners of your project, such as affiliated universities or sponsors. If you upload them into this group, they will show in your footer and can be linked to the respective home pages.
- People Images: If you want to show your team and project participants, you can upload portrait photos here and create an "About Us" page. On it, your team is shown with name and function in arranged cards.
- Background Images: You can have jumbotrons (banners, normally on the top of a page) with background images.
- Slideshow Images: You can create slideshows (see UI Elements). The used images need to be uploaded ind this group.